# Script for the preprocessing of drug data for ISBRA-TCBB paper

# W1, W2 and W3 are the unpreprocessed integrated matrices:
# W1 : Tanimoto similarity only
# W2 : Tanimoto + DrugBank drug-target
# W3 : Tanimoto + DrugBank drug-target + STITCH Drug-Chemical
# W1L, W2L and W3L are the corresponding preprocessed integrated matrices with graph Laplacian normalization

library(NetPreProc);


# Label matrix with the 51 original therapeutic categories
load("Original_labels.rda");  # T

save(T, file="T.rda");

DrugBank.classes <- colnames(T);
drugs <- rownames(T);
n.DrugBank.classes <- apply(T,2,sum);

# Full label matrix of Drug classes
load("Labels_full_DB3.rda");  # T.full.db3  1253 X 457

save(T.full.db3, file ="T.full.db3.rda");

DrugBank.classes.full <- colnames(T.full.db3);
n.DrugBank.classes.full <- apply(T.full.db3,2,sum);

#Loading Chemical normalized Tanimoto similarity between drugs (binary matrix: 1 for coeff >= 0.5 otherwise 0)
load("W_matrices.rda"); # W  14263 edges

W1 <- Tanimoto <- W;

W1L <- Laplacian.norm(W);

# Drug Target projection matrix (binary mode projection)

load("W2_matrices.rda"); # W2 45080 edges

Drug.Target <- W2;

Drug.Target.L <- Laplacian.norm(Drug.Target);

W2 <- Tanimoto + Drug.Target;

W2L <- W1L + Drug.Target.L;


# Drug-Chem STITCH projection matrix (binary mode projection)

load("W3_matrices.rda"); # W3 97964 edges

Drug.Chem <- W3;

Drug.Chem.L <- Laplacian.norm(Drug.Chem);

W3 <- W2 + Drug.Chem;

W3L <- W2L + Drug.Chem.L;


# saving matrices
save(Tanimoto, Drug.Target, Drug.Chem, file="SingleMatrices.rda");
save(W1, W2, W3, file="Wmatrices.rda");
save(W1L, W2L, W3L, file="WLmatrices.rda");


