# General function to perform experiments with RWR
# July 2012

library(PerfMeas);
library(NetPreProc);
source("sw/RWR.R");

# do.RWR.old
# High level function to perform experiments with RWR
# It perform a 5 fold CV repeated 1 time and 10 times on a given data set
# INPUT:
# gamma : restart parameter (def: 0.6) 
# tmax : maximum number of iterations (def: 1000)
# eps : maximum allowed difference between the computed probabilities at the steady state (def. 1e-10)
# filter : if TRUE (def) the adjacnecy matrix is sparsified otherwise not
# data : name of the data set to loaded (without rda extension). It must be  an .rda file containing the adjiacency matrix of the graph. 
#        It assumes that it is in the "data" directory
# labels : name of the target labels (without rda extension). It must be  an .rda file containing the label matrix of the examples.
#          It assumes that it is in the "data" directory
do.RWR.old  <- function(gamma=0.6, tmax=1000, eps=1e-10, data, labels)  {

  recall.levels <- c(0.01, 0.05, seq(from=0.1, to=1, by=0.1));
  
  # loading the adjacency matrix
  dataset.name <- paste0("data/",data,".rda");
  data.name=load(dataset.name);
  K=eval(parse(text=data.name));  # K represents the adjacency matrix
  K[K<0]<-0;

  # loading labels matrix
  dataset.name <- paste0("data/",labels,".rda");
  x=load(dataset.name);
  T=eval(parse(text=x));  # T represents the label matrix

  nclasses <- ncol(T);
  ndrugs <- nrow(T);
  
  if (ndrugs != nrow(K))
    stop("do.RWR.old: adjacency and label matrices do not agree");
  
  #if (filter)
  #K <- Sparsify.matrix(K, k=1); 
  #K <-Prob.norm(K); 

  # construction of the matrix of scores. 
  S1  <- matrix(numeric(nclasses * ndrugs), nrow=ndrugs);
  drugnames<-rownames(T);
  classnames<-colnames(T);
  rownames(S1) <- drugnames;
  colnames(S1) <- classnames;

  # computing scores for each class
  for (i in 1:nclasses)  {
    ind.pos <- which(T[,i]==1);
    # 1 CV
    res <- RW.cv(K, ind.pos, k=5, init.seed=0, fun=RWR, gamma=gamma, tmax=tmax, eps=eps, norm=FALSE); 
    S1[,i] <- res;
    cat("Class ", i, " : ", classnames[i], "\n");
  }

  # saving scores
  
  score.file = paste0("ResultsOld/Scores.","RWR.","g",gamma,".",data.name,".rda");
  save(S1, file=score.file);
  
  # computing and saving AUC  
  
  AUC.S1 <- AUC.single.over.classes(T, S1);
  
  AUC.file = paste0("ResultsOld/AUC.","RWR.","g",gamma,".",data.name,".rda");  
  save(AUC.S1, file=AUC.file);

  # computing and saving PXR 
  PXR.S1 <- precision.at.multiple.recall.level.over.classes (T, S1, rec.level=recall.levels);

  PXR.file = paste0("ResultsOld/PXR.","RWR.","g",gamma,".",data.name,".rda");  
  
  save(PXR.S1, file=PXR.file);
  
}
